fnss.topologies.parsers.parse_abilene — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_abilene

`parse_abilene`(topology_path, links_path=None)

  Parse the Abilene topology.

  Parameters: | topology_path : str The path of the Abilene topology file links_path : str, optional The path of the Abilene links file
  Returns: | topology : DirectedTopology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »